@@ -34,22 +34,27 @@ function(pvals, FDR=.1){
     max(c(0,which(pvals<=FDR*(1:length(pvals))/length(pvals))))
 }
 
-`.biweight` <- 
-function(x, K=6, max.iter=20){
+`.biweight.FTICRMS` <-
+function(x, K=9, max.iter=20, na.rm=TRUE){
+    if(!na.rm && sum(is.na(x))>0){
+        return(NA)
+    } else {
+        x <- x[!is.na(x)]
+    }
     iter <- 0
     ind.old <- 0
     ind.new <- 1
     center.bw <- median(x)
     scale.bw <- median(abs(x-center.bw))
-    while(!all(ind.old==ind.new) && iter<max.iter){
+    while(!identical(ind.old,ind.new) && iter<max.iter){
         iter <- iter + 1
         ind.old <- ind.new
         u <- (x-center.bw)/scale.bw
         ind.new <- (abs(u) <= K)
-        center.bw <- sum(ind.new * x * (1-(u/K)^2)^2)/sum(ind.new * (1-(u/K)^2)^2)   
+        center.bw <- sum(ind.new * x * (1-(u/K)^2)^2)/sum(ind.new * (1-(u/K)^2)^2)
         scale.bw <- median(abs(x-center.bw))
     }
-    if(iter == max.iter && !all(ind.old==ind.new)){
+    if(iter == max.iter && !identical(ind.old,ind.new)){
         warning(paste("Iteration limit of", max.iter, "reached without convergence."))
     }
     list(center = center.bw, scale = scale.bw, iter = iter)
