@@ -1,24 +1,24 @@
 `make.par.file` <-
-function(covariates, form, root.dir=".", par.file="parameters.RData", ...){
+function(covariates, form, par.file="parameters.RData", root.dir=".", ...){
     default.vals <- list(
         add.norm = TRUE,
-        add.par = 10,
+        add.par = 0,
         align.method = "spline",
-        base.dir = paste(root.dir, "/Baseline_Corrected", sep=""),
-        calc.all.peaks = TRUE,
-        clust.constant = 10,
-        clust.method = "ppm",
+        base.dir = paste(root.dir, "/Baselines", sep=""),
+        calc.all.peaks = FALSE,
+        cluster.constant = 10,
+        cluster.method = "ppm",
         cor.thresh = 0.8,
         FDR = 0.1,
-        frac.changed = 0.001,
+        gengamma.quantiles = TRUE,
         isotope.dist = 7,
-        k.biweight = 6,
-        lrg.dir = paste(root.dir, "/Large_Peaks", sep=""), 
-        lrg.file = "lrg.peaks.RData",
+        lrg.dir = paste(root.dir, "/Large_Peaks", sep=""),
+        lrg.file = "lrg_peaks.RData",
         lrg.only = TRUE,
         masses = NULL,
-        max.iter = 30,
-        neg.pen = sqrt(pi/2),
+        max.iter = 40,
+        neg.div = NA,
+        neg.norm.by = c("baseline", "overestimate", "constant"),
         normalization = "common",
         num.pts = 5,
         oneside.min = 1,
@@ -26,17 +26,24 @@ function(covariates, form, root.dir=".", par.file="parameters.RData", ...){
         par.file = "parameters.RData",
         peak.dir = paste(root.dir, "/All_Peaks", sep=""),
         peak.method = "parabola",
+        peak.thresh = 4.5,
         pre.align = FALSE,
         pval.fcn = "default",
         R2.thresh = 0.98,
         raw.dir = paste(root.dir, "/Raw_Data", sep=""),
+        rel.conv.crit = TRUE,
         repl.method = max,
         res.dir = paste(root.dir, "/Results", sep=""),
         res.file = "analyzed.RData",
         root.dir = ".",
-        sm.par = 1.1E-9,
+        sm.div = NA,
+        sm.norm.by = c("baseline", "overestimate", "constant"),
+        sm.ord = 2,
+        sm.par = 1e-11,
+        subtract.base = FALSE,
+        tol = 5e-8,
         trans.method = "shiftedlog",
-        use.t.test = TRUE
+        use.t.test = FALSE
     )
     new.vals <- c(list(...), root.dir=root.dir, par.file=par.file)
     for(i in names(default.vals)){
