@@ -1,10 +1,11 @@
 `run.cluster.matrix` <-
-function(pre.align = FALSE, align.method = "spline", trans.method="shiftedlog", 
-        add.par = 10, lrg.only = TRUE, masses = NULL, isotope.dist = 7,
-        cluster.method = "ppm", cluster.constant = 10, root.dir = ".", base.dir, 
-        peak.dir, lrg.dir, lrg.file = "lrg.peaks.RData", overwrite = FALSE, 
-        use.par.file = FALSE, par.file = "parameters.RData"){
-    if(missing(base.dir)){base.dir <- paste(root.dir, "/Baseline_Corrected", sep="")}
+function(pre.align = FALSE, align.method = "spline", trans.method = "shiftedlog",
+        add.par = 0, subtract.base = FALSE, lrg.only = TRUE, calc.all.peaks = FALSE,
+        masses = NULL, isotope.dist = 7, cluster.method = "ppm", cluster.constant = 10,
+        num.pts = 5, R2.thresh = 0.98, oneside.min = 1, peak.method = "parabola",
+        root.dir = ".", base.dir, peak.dir, lrg.dir, lrg.file = "lrg_peaks.RData",
+        overwrite = FALSE, use.par.file = FALSE, par.file = "parameters.RData"){
+    if(missing(base.dir)){base.dir <- paste(root.dir, "/Baselines", sep="")}
     if(missing(peak.dir)){peak.dir <- paste(root.dir, "/All_Peaks", sep="")}
     if(missing(lrg.dir)){lrg.dir <- paste(root.dir, "/Large_Peaks", sep="")}
     if(use.par.file){
@@ -13,6 +14,7 @@ function(pre.align = FALSE, align.method = "spline", trans.method="shiftedlog",
     if(is.null(masses) && !lrg.only){
         stop("Either lrg.only must be TRUE or masses must be defined (or both)")
     }
+    zeros <- 0
     load(paste(lrg.dir, "/", lrg.file, sep=""))
     if(!exists("clust.mat") || overwrite){
         if(is.na(amps) && align.method!="none"){
@@ -49,7 +51,7 @@ function(pre.align = FALSE, align.method = "spline", trans.method="shiftedlog",
             }
         }
 
-        peaks.clustered <- .cluster.peaks(lrg.peaks, clust.method, clust.constant)
+        peaks.clustered <- .cluster.peaks(lrg.peaks, cluster.method, cluster.constant)
         peaks.clustered <- .break.dups(peaks.clustered)
         clust.mat <- .cluster.matrix(peaks.clustered)
         rm(peaks.clustered)
@@ -73,7 +75,7 @@ function(pre.align = FALSE, align.method = "spline", trans.method="shiftedlog",
         }
         num.sig <- apply(!is.na(clust.mat), 1, sum)
         ran <- matrix(sapply(strsplit(rownames(clust.mat),","),as.numeric),
-            ncol=2,byrow=TRUE)
+            ncol=2, byrow=TRUE)
         for(f in names(clust.mat)){
             load(paste(peak.dir, "/", f, "_peaks.RData", sep=""))
             if(!identical(pre.align, FALSE)){
@@ -99,46 +101,77 @@ function(pre.align = FALSE, align.method = "spline", trans.method="shiftedlog",
 
             if(any(is.na(clust.mat[,f]))){
                 load(paste(base.dir, "/", f, ".RData", sep=""))
-                names(peak.base) <- c("Freq","LogAmp")
-                if(trans.method == "shiftedlog"){
-                    peak.base$LogAmp <- log(peak.base$LogAmp+add.par-min(peak.base$LogAmp))
+                names(spect) <- c("Freq","LogAmp")
+                if(subtract.base){
+                    spect$LogAmp <- spect$LogAmp-spect.base
+                } else if(any(spect$LogAmp == 0)){
+                    zeros <- zeros + 1
+                    spect$LogAmp[spect$LogAmp == 0] <- min(spect$LogAmp[spect$LogAmp > 0])
                 }
-                if(trans.method=="glog"){
-                    peak.base$LogAmp <- log((peak.base$LogAmp+sqrt(add.par + peak.base$LogAmp^2))/2)
+                if(trans.method=="shiftedlog"){
+                    if(subtract.base){
+                        add.par <- add.par - min(spect$LogAmp)
+                    }
+                    spect$LogAmp <- log(spect$LogAmp+add.par)
+                } else if(trans.method=="glog"){
+                    spect$LogAmp <- log((spect$LogAmp+sqrt(add.par + spect$LogAmp^2))/2)
                 }
                 if(!identical(pre.align, FALSE)){
                     if(identical(class(pre.spl[[f]]),"lm")){
-                        peak.base$Freq <- predict(pre.spl[[f]], data.frame(X=peak.base$Freq))
+                        spect$Freq <- predict(pre.spl[[f]], data.frame(X=spect$Freq))
                     } else {
-                        peak.base$Freq <- predict(pre.spl[[f]], peak.base$Freq)$y
+                        spect$Freq <- predict(pre.spl[[f]], spect$Freq)$y
                     }
                 }
                 if(align.method=="spline"){
-                    peak.base$Freq <- predict(spl[[f]], peak.base$Freq)$y
+                    spect$Freq <- predict(spl[[f]], spect$Freq)$y
                 }
-                peak.base <- peak.base[order(peak.base$Freq),]
+                spect <- spect[order(spect$Freq),]
                 locs <- which(is.na(clust.mat[,f]))
                 endpts <- as.numeric(t(ran[locs,,drop=FALSE]))
-                ints <- findInterval(peak.base$Freq, endpts, rightmost.closed=TRUE)
+                ints <- findInterval(spect$Freq, endpts, rightmost.closed=TRUE)
                 ints <- (ints * (ints %% 2)+1)/2
-                all.peaks <- data.frame(Int = ints[ints>.75], Max_hat=peak.base$LogAmp[ints>.75])
+                if(!calc.all.peaks){
+                    ints1 <- intersect(which(ints>.75), .loc.maxes(spect$LogAmp))
+                    thresh <- rep(Inf, dim(spect)[1])
+                    thresh[ints1] <- -Inf
+                    all.peaks <- locate.peaks(spect, num.pts, R2.thresh,
+                        oneside.min, peak.method, thresh)
+                    ints1 <- findInterval(all.peaks$Center_hat, endpts, rightmost.closed=TRUE)
+                    ints1 <- (ints1 * (ints1 %% 2)+1)/2
+                    all.peaks <- data.frame(Int = ints1[ints1>.75], Max_hat=all.peaks$Max_hat[ints1>.75])
+                    if(dim(all.peaks)[1]){
+                        all.peaks <- unlist(by(all.peaks$Max_hat,all.peaks$Int,max))
+                        clust.mat[locs[as.numeric(names(all.peaks))],f] <- all.peaks
+                    }
+                    rm(all.peaks)
+
+                }
+                locs <- which(is.na(clust.mat[,f]))
+                endpts <- as.numeric(t(ran[locs,,drop=FALSE]))
+                ints <- findInterval(spect$Freq, endpts, rightmost.closed=TRUE)
+                ints <- (ints * (ints %% 2)+1)/2
+                all.peaks <- data.frame(Int = ints[ints>.75], Max_hat=spect$LogAmp[ints>.75])
                 if(dim(all.peaks)[1]){
                     all.peaks <- unlist(by(all.peaks$Max_hat,all.peaks$Int,max))
                     clust.mat[locs[as.numeric(names(all.peaks))],f] <- all.peaks
                 }
                 if(any(is.na(clust.mat[,f]))){
                     locs <- which(is.na(clust.mat[,f]))
-                    ends <- findInterval(apply(ran[locs,,drop=FALSE],1,mean), peak.base$Freq,
+                    ends <- findInterval(apply(ran[locs,,drop=FALSE],1,mean), spect$Freq,
                         all.inside=TRUE)
-                    ends2 <- apply(abs(cbind(peak.base$Freq[ends],peak.base$Freq[ends+1]) -
+                    ends2 <- apply(abs(cbind(spect$Freq[ends],spect$Freq[ends+1]) -
                         apply(ran[locs,,drop=FALSE],1,mean)), 1, which.min)
-                    clust.mat[locs,f] <- peak.base$LogAmp[ends+ends2-1]
+                    clust.mat[locs,f] <- spect$LogAmp[ends+ends2-1]
 
                 }
-                rm(peak.base)
+                rm(spect)
             }
         }
-        save(lrg.peaks,clust.mat,amps,centers,num.sig, file=paste(lrg.dir, "/", 
+        if(zeros){
+            warning(paste(zeros, ifelse(zeros==1, "spectrum", "spectra"), "had one or more zero entries for amplitude; those entries replaced by minimum value of amplitude"))
+        }
+        save(lrg.peaks,clust.mat,amps,centers,num.sig, file=paste(lrg.dir, "/",
             lrg.file, sep=""))
     } else {
         warning("File created by previous run of run.cluster.matrix exists and overwrite = FALSE; file not updated")
